---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE REQUEST] Title Here"
labels: enhancement
assignees: HideyoshiNakazone

---

**Is this a [Json Schema](https://json-schema.org/specification) Keyword that is missing?** [yes|no]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Additional context**
Add any other context or screenshots about the feature request here.
